<?php
/* Smarty version 4.5.3, created on 2025-10-17 21:21:03
  from '/srv/easystream/f_templates/tpl_frontend/tpl_header/tpl_headernav_pop.tpl' */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '4.5.3',
  'unifunc' => 'content_68f2b33f45f669_64452478',
  'has_nocache_code' => true,
  'file_dependency' => 
  array (
    '72ce588dcc69214f9440c8b802f4336c287be2cf' => 
    array (
      0 => '/srv/easystream/f_templates/tpl_frontend/tpl_header/tpl_headernav_pop.tpl',
      1 => 1760556072,
      2 => 'file',
    ),
  ),
  'includes' => 
  array (
  ),
),false)) {
function content_68f2b33f45f669_64452478 (Smarty_Internal_Template $_smarty_tpl) {
$_smarty_tpl->_checkPlugins(array(0=>array('file'=>'/srv/easystream/f_core/f_classes/class_smarty/plugins/function.lang_entry.php','function'=>'smarty_function_lang_entry',),1=>array('file'=>'/srv/easystream/f_core/f_classes/class_smarty/plugins/function.href_entry.php','function'=>'smarty_function_href_entry',),2=>array('file'=>'/srv/easystream/f_core/f_classes/class_smarty/plugins/modifier.strpos.php','function'=>'smarty_modifier_strpos',),));
if ($_SESSION['USER_ID'] > 0) {?>
<div class="tacc-img">
	<img height="40" class="own-profile-image mt-off" title="<?php echo $_SESSION['USER_NAME'];?>
" alt="<?php echo $_SESSION['USER_NAME'];?>
" src="<?php $_smarty_tpl->assign("profileImage" , insert_getProfileImage (array('for' => ((string)$_SESSION['USER_ID'])),$_smarty_tpl), true);
echo $_smarty_tpl->tpl_vars['profileImage']->value;?>
">
</div>
<div class="tacc-nfo">
        <span>
                <span class="tacc-uu"><?php if ($_SESSION['USER_ID'] > 0) {?><a href="<?php echo $_smarty_tpl->tpl_vars['main_url']->value;?>
/@<?php echo $_SESSION['USER_NAME'];?>
"><?php if ($_SESSION['USER_DNAME'] != '') {
echo $_SESSION['USER_DNAME'];
} else {
echo $_SESSION['USER_NAME'];
}?></a><?php } else {
echo smarty_function_lang_entry(array('key'=>"frontend.global.guest.rand"),$_smarty_tpl);
}?></span>
                <span class="tacc-us">
                <?php if ($_smarty_tpl->tpl_vars['user_follows']->value) {?>
                	<span class="r2"><?php if ($_SESSION['USER_ID'] > 0) {
echo insert_getFollowCount(array(),$_smarty_tpl);
} else { ?>0<?php }?> <label><?php echo smarty_function_lang_entry(array('key'=>"frontend.global.followers"),$_smarty_tpl);?>
</label></span>
                <?php }?>
                <?php if ($_smarty_tpl->tpl_vars['user_subscriptions']->value) {?>
                	<span class="r1"><?php if ($_SESSION['USER_ID'] > 0) {
echo insert_getSubCount(array(),$_smarty_tpl);
} else { ?>0<?php }?> <label><?php echo smarty_function_lang_entry(array('key'=>"frontend.global.subscribers"),$_smarty_tpl);?>
</label></span>
                <?php }?>
                </span>
        </span>
</div>
<div class="clearfix"></div>
<?php }?>

<ul class="accordion tacc" id="top-session-accordion">
<?php if ($_SESSION['USER_ID'] > 0) {?>
<li class=""><a class="dcjq-parent" href="<?php echo $_smarty_tpl->tpl_vars['main_url']->value;?>
/<?php echo smarty_function_href_entry(array('key'=>"files"),$_smarty_tpl);?>
"><i class="icon-upload"></i> <?php echo smarty_function_lang_entry(array('key'=>"subnav.entry.files.my"),$_smarty_tpl);?>
</a></li>
<?php if ($_smarty_tpl->tpl_vars['user_subscriptions']->value == 1) {?>
<li class=""><a class="dcjq-parent" href="<?php echo $_smarty_tpl->tpl_vars['main_url']->value;?>
/<?php echo smarty_function_href_entry(array('key'=>"subscribers"),$_smarty_tpl);?>
"><i class="icon-coin"></i> <?php echo smarty_function_lang_entry(array('key'=>"subnav.entry.subpanel"),$_smarty_tpl);?>
</a></li>
<?php }
if ($_smarty_tpl->tpl_vars['user_tokens']->value == 1) {?>
<li class=""><a class="dcjq-parent" href="<?php echo $_smarty_tpl->tpl_vars['main_url']->value;?>
/<?php echo smarty_function_href_entry(array('key'=>"tokens"),$_smarty_tpl);?>
"><i class="icon-coin"></i> <?php echo smarty_function_lang_entry(array('key'=>"subnav.entry.tokenpanel"),$_smarty_tpl);?>
</a></li>
<?php }?>
<li class=""><a class="dcjq-parent" href="<?php echo $_smarty_tpl->tpl_vars['main_url']->value;?>
/<?php echo smarty_function_href_entry(array('key'=>"account"),$_smarty_tpl);?>
"><i class="icon-user"></i> <?php echo smarty_function_lang_entry(array('key'=>"subnav.entry.account.my"),$_smarty_tpl);?>
</a></li>
<li class=""><a class="dcjq-parent" href="<?php echo $_smarty_tpl->tpl_vars['main_url']->value;?>
/<?php echo smarty_function_href_entry(array('key'=>"manage_channel"),$_smarty_tpl);?>
"><i class="icon-settings"></i> <?php echo smarty_function_lang_entry(array('key'=>"subnav.entry.channel.my"),$_smarty_tpl);?>
</a></li>
<li class=""><a class="dcjq-parent" href="<?php echo $_smarty_tpl->tpl_vars['main_url']->value;?>
/<?php if ($_smarty_tpl->tpl_vars['internal_messaging']->value == 1 && ($_smarty_tpl->tpl_vars['user_friends']->value == 1 || $_smarty_tpl->tpl_vars['user_blocking']->value == 1)) {
echo smarty_function_href_entry(array('key'=>"messages"),$_smarty_tpl);
} elseif ($_smarty_tpl->tpl_vars['internal_messaging']->value == 0 && ($_smarty_tpl->tpl_vars['user_friends']->value == 1 || $_smarty_tpl->tpl_vars['user_blocking']->value == 1)) {
echo smarty_function_href_entry(array('key'=>"contacts"),$_smarty_tpl);
}?>"><i class="icon-envelope"></i> <?php if ($_smarty_tpl->tpl_vars['internal_messaging']->value == 1 && ($_smarty_tpl->tpl_vars['user_friends']->value == 1 || $_smarty_tpl->tpl_vars['user_blocking']->value == 1)) {
echo smarty_function_lang_entry(array('key'=>"subnav.entry.contacts.messages"),$_smarty_tpl);
} elseif ($_smarty_tpl->tpl_vars['internal_messaging']->value == 0 && ($_smarty_tpl->tpl_vars['user_friends']->value == 1 || $_smarty_tpl->tpl_vars['user_blocking']->value == 1)) {
echo smarty_function_lang_entry(array('key'=>"subnav.entry.contacts"),$_smarty_tpl);
}?> <?php echo insert_newMessages(array(),$_smarty_tpl);?></a></li>
<li><div class="line"></div></li>
<?php }?>
<li class="">
	<a class="dcjq-parent a-dt" href="javascript:;" rel="nofollow"><i class="icon-contrast"></i> <?php echo smarty_function_lang_entry(array('key'=>"frontend.global.darktheme"),$_smarty_tpl);?>
: <span id="dark-mode-state-text"><?php if (smarty_modifier_strpos($_smarty_tpl->tpl_vars['theme_name']->value,'dark')) {
echo smarty_function_lang_entry(array('key'=>"frontend.global.on.text"),$_smarty_tpl);
} else {
echo smarty_function_lang_entry(array('key'=>"frontend.global.off.text"),$_smarty_tpl);
}?></span><i class="iconBe-chevron-right place-right"></i></a>
</li>
<li id="l-dt" style="display:none">
	<div class="dm-wrap">
		<div class="dm-head dm-head-dt"><i class="icon-arrow-left2"></i> <?php echo smarty_function_lang_entry(array('key'=>"frontend.global.darktheme"),$_smarty_tpl);?>
</div>
		<p><?php echo smarty_function_lang_entry(array('key'=>"frontend.global.darktheme.tip1"),$_smarty_tpl);?>
<br><br><?php echo smarty_function_lang_entry(array('key'=>"frontend.global.darktheme.tip2"),$_smarty_tpl);?>

		<div>
			<span class="label"><?php echo smarty_function_lang_entry(array('key'=>"frontend.global.darktheme"),$_smarty_tpl);?>
</span>
			<?php echo insert_themeSwitch(array(),$_smarty_tpl);?>
		</div>
	</div>
</li>
<?php if ($_SESSION['lang_count'] > 1) {?>
<li class="">
	<?php echo insert_langInit(array(),$_smarty_tpl);?>
</li>
<?php }
if ($_SESSION['USER_ID'] > 0) {?>
<li class=""><a class="dcjq-parent" href="<?php echo $_smarty_tpl->tpl_vars['main_url']->value;?>
/<?php echo smarty_function_href_entry(array('key'=>"signout"),$_smarty_tpl);?>
"><i class="icon-exit"></i> <?php echo smarty_function_lang_entry(array('key'=>"frontend.global.signout"),$_smarty_tpl);?>
</a></li>
<?php } else { ?>
<li class=""><a class="dcjq-parent" href="<?php echo $_smarty_tpl->tpl_vars['main_url']->value;?>
/<?php echo smarty_function_href_entry(array('key'=>"signin"),$_smarty_tpl);?>
"><i class="icon-exit"></i> <?php echo smarty_function_lang_entry(array('key'=>"frontend.global.signin"),$_smarty_tpl);?>
</a></li>
<?php }?>
</ul>

<?php echo '<script'; ?>
 type="text/javascript">
$('a.a-dt').click(function(){$('#user-arrow-box #top-session-accordion li').hide();$('#l-dt').show()});
$('.dm-head-dt').click(function(){$('#user-arrow-box #top-session-accordion li').show();$('#l-dt, #l-ln').hide()});
$('a.a-ln').click(function(){$('#user-arrow-box #top-session-accordion li').hide();$('#l-ln').show()});
$('.dm-head-ln').click(function(){$('#user-arrow-box #top-session-accordion li').show();$('#l-ln, #l-dt').hide()});
<?php echo '</script'; ?>
>

<?php }
}
